mercurial/cmdutil.py
branchstable
changeset 10953 f1250e2e8fd1
parent 10463 5ddde896a19d
child 10962 8d5f5122a732
--- a/mercurial/cmdutil.py	Wed Apr 07 02:41:22 2010 +0200
+++ b/mercurial/cmdutil.py	Thu Apr 08 00:13:33 2010 +0900
@@ -129,9 +129,10 @@
     if r:
         dst.setconfig('bundle', 'mainreporoot', r)
 
-    # copy auth section settings
-    for key, val in src.configitems('auth'):
-        dst.setconfig('auth', key, val)
+    # copy auth and http_proxy section settings
+    for sect in ('auth', 'http_proxy'):
+        for key, val in src.configitems(sect):
+            dst.setconfig(sect, key, val)
 
     return dst